%define major_c 7
%define libname %mklibname %{name} %{major_c}
%define develname %mklibname -d %{name}

Summary:	Libraries to use the Unidata network Common Data Form (netCDF)
Name:		netcdf
Version:	4.2.1.1
Release:	%mkrel 4
Group:		Development/C
License:	NetCDF
URL:		http://www.unidata.ucar.edu/packages/netcdf/index.html
Source0:	http://www.unidata.ucar.edu/downloads/netcdf/ftp/netcdf-%{version}.tar.gz
Patch2:		netcdf-4.2.1.1-pkgconfig.patch
Requires(post): info-install
Requires(postun): info-install
BuildRequires:  hdf5-devel
BuildRequires:  libcurl-devel
BuildRequires:  zlib-devel
%ifnarch %arm %mips
BuildRequires:  valgrind
%endif
BuildRequires:	texinfo
BuildRequires:	tetex-latex
BuildRequires:	groff

%description
NetCDF (network Common Data Form) is an interface for array-oriented data
access and a freely-distributed collection of software libraries for C, 
Fortran, C++, and perl that provides an implementation of the interface.
The netCDF library also defines a machine-independent format for representing
scientific data. Together, the interface, library, and format support the 
creation, access, and sharing of scientific data. The netCDF software was 
developed at the Unidata Program Center in Boulder, Colorado.

NetCDF data is: 

   o Self-Describing. A netCDF file includes information about the data it
     contains. 

   o Network-transparent. A netCDF file is represented in a form that can be 
     accessed by computers with different ways of storing integers, characters,
     and floating-point numbers. 

   o Direct-access. A small subset of a large dataset may be accessed 
     efficiently, without first reading through all the preceding data. 

   o Appendable. Data can be appended to a netCDF dataset along one dimension 
     without copying the dataset or redefining its structure. The structure of 
     a netCDF dataset can be changed, though this sometimes causes the dataset 
     to be copied. 

   o Sharable. One writer and multiple readers may simultaneously access the 
     same netCDF file. 

%package -n	%{libname}
Summary:	C libraries for netcdf-4
Group:		System/Libraries
Provides:	lib%{name} = %{version}

%description -n	%{libname}
This package contains the netCDF-4 C libraries.

%package -n	%{develname}
Summary:	Development files for netcdf-4
Group:		Development/C
Requires:	%{name} = %{version}-%{release}
Provides:	lib%{name}-devel = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}
Obsoletes:	%{name}-devel < 4.0
Conflicts:	%{name} < 4.1

%description -n %{develname}
This package contains the netCDF-4 header files, shared devel libs, and 
man pages.

%prep
%setup -q
%patch2 -p1

%build
%configure2_5x --enable-shared --disable-static \
		--enable-netcdf-4 \
		--enable-dap \
           	--enable-extra-example-tests \
		--disable-dap-remote-tests

%make

%check
make check

%install
%makeinstall_std
rm -f %{buildroot}%{_libdir}/*.la

%files
%doc COPYRIGHT README RELEASE_NOTES
%{_bindir}/ncgen
%{_bindir}/ncgen3
%{_bindir}/ncdump
%{_bindir}/nccopy
%{_mandir}/man1/*.1*

%files -n %{libname}
%{_libdir}/libnetcdf.so.%{major_c}*

%files -n %{develname}
%{_bindir}/nc-config
%{_includedir}/*.h
%{_libdir}/*.so
%{_mandir}/man3/*.3*
%{_libdir}/pkgconfig/*.pc


%changelog

* Mon Mar 11 2013 rtp <rtp> 4.2.1.1-4.mga3
+ Revision: 402083
- disable valgrind on arm/mips

  + umeabot <umeabot>
    - Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Fri Oct 12 2012 fwang <fwang> 4.2.1.1-2.mga3
+ Revision: 305116
- rebuild for new hdf5

* Wed Sep 19 2012 fwang <fwang> 4.2.1.1-1.mga3
+ Revision: 296140
- cleanup spec
- upload patch
- rediff pkgconfig patch
- new version 4.2.1.1

* Fri Apr 06 2012 fwang <fwang> 4.1.3-3.mga2
+ Revision: 228846
- rebuild for new gcc (bug#5228)
- fix provides
- update file list
- new verison 4.1.3

  + dmorgan <dmorgan>
    - Rebuild against new hdf5

* Thu Feb 17 2011 ahmad <ahmad> 4.1.1-3.mga1
+ Revision: 53318
- drop old/unneeded scriptlets
- imported package netcdf


* Fri Dec 03 2010 Oden Eriksson <oeriksson@mandriva.com> 4.1.1-2mdv2011.0
+ Revision: 606819
- rebuild

* Sun Apr 25 2010 Emmanuel Andry <eandry@mandriva.org> 4.1.1-1mdv2010.1
+ Revision: 538712
- New version 4.1.1
- fix obsoletes

* Wed Feb 17 2010 Emmanuel Andry <eandry@mandriva.org> 4.1-1mdv2010.1
+ Revision: 506886
- BR tetex-latex
- netcdf doesn't like parallel on bs
- enable ncgen4 and dap
- disable dap remote tests

  + Funda Wang <fwang@mandriva.org>
    - fix build
    - New version 4.1

* Mon Jan 18 2010 Emmanuel Andry <eandry@mandriva.org> 4.0.1-11mdv2010.1
+ Revision: 493073
- try to workaround linking issues against hdf5 disabling ld_no_undefined

* Sun Jan 17 2010 Emmanuel Andry <eandry@mandriva.org> 4.0.1-10mdv2010.1
+ Revision: 492772
- rebuild for hdf5

* Sat Jan 16 2010 Emmanuel Andry <eandry@mandriva.org> 4.0.1-9mdv2010.1
+ Revision: 492328
- update p0

* Fri Jan 15 2010 Emmanuel Andry <eandry@mandriva.org> 4.0.1-8mdv2010.1
+ Revision: 491906
- add needed requires for devel package

* Fri Jan 15 2010 Emmanuel Andry <eandry@mandriva.org> 4.0.1-7mdv2010.1
+ Revision: 491886
- do not obsolete provided library

* Fri Jan 15 2010 Emmanuel Andry <eandry@mandriva.org> 4.0.1-6mdv2010.1
+ Revision: 491864
- enable netcdf 4
- add linking patch from gentoo
- split libraries by languages
- fix obsoletes/provides

* Thu Aug 20 2009 Emmanuel Andry <eandry@mandriva.org> 4.0.1-5mdv2010.0
+ Revision: 418729
- disable netcdf 4 for now

* Thu Aug 20 2009 Emmanuel Andry <eandry@mandriva.org> 4.0.1-4mdv2010.0
+ Revision: 418635
- add missing provides

* Thu Aug 20 2009 Emmanuel Andry <eandry@mandriva.org> 4.0.1-3mdv2010.0
+ Revision: 418622
- enable ncgen4
  explicit hdf5-devel for devel package

* Thu Aug 20 2009 Emmanuel Andry <eandry@mandriva.org> 4.0.1-2mdv2010.0
+ Revision: 418610
- obsoletes old devel package to ease upgrade

* Thu Aug 20 2009 Emmanuel Andry <eandry@mandriva.org> 4.0.1-1mdv2010.0
+ Revision: 418519
- use libraries policy
- new majors 5 and 6
- disable test (1 test fails)
- New version 4.0.1
- drop P0
- update P1
- build with netcdf4 support (requires HDF5)
- update descriptions

* Fri Apr 10 2009 Funda Wang <fwang@mandriva.org> 4.0-1mdv2009.1
+ Revision: 365885
- fix str fmt

* Thu Aug 14 2008 Emmanuel Andry <eandry@mandriva.org> 4.0-1mdv2009.0
+ Revision: 271832
- New version
- fix license

* Sun Jul 06 2008 Oden Eriksson <oeriksson@mandriva.com> 3.6.3-1mdv2009.0
+ Revision: 232195
- 3.6.3
- added a patch from gentoo, though it won't help much
- use _disable_ld_as_needed and _disable_ld_no_undefined to make it build

  + Thierry Vignaud <tv@mandriva.org>
    - rebuild

  + Pixel <pixel@mandriva.com>
    - do not call ldconfig in %%post/%%postun, it is now handled by filetriggers

  + Olivier Thauvin <nanardon@mandriva.org>
    - unzip source in %%install instead %%check

* Sun Jan 20 2008 Emmanuel Andry <eandry@mandriva.org> 3.6.2-4mdv2008.1
+ Revision: 155303
- fix devel static package name
- drop obsoletes

* Sat Jan 19 2008 Emmanuel Andry <eandry@mandriva.org> 3.6.2-3mdv2008.1
+ Revision: 155130
- fix obsoletes

* Sat Jan 19 2008 Emmanuel Andry <eandry@mandriva.org> 3.6.2-2mdv2008.1
+ Revision: 155081
- rebuild

* Thu Jan 03 2008 Emmanuel Andry <eandry@mandriva.org> 3.6.2-1mdv2008.1
+ Revision: 144107
- import netcdf


